# sitelib for noarch packages, sitearch for others (remove the unneeded one)
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}

%define compdir %(pkg-config --variable=completionsdir bash-completion)
%if "%{compdir}" == ""
%define compdir "/etc/bash_completion.d"
%endif

Name:           fedpkg
Version:        1.37
Release:        16.20191206gite9889c3b%{?dist}
Summary:        Fedora utility for working with dist-git

License:        GPLv2+
URL:            https://pagure.io/fedpkg
Source0:        fedpkg-e9889c3b.tar

BuildArch:      noarch

# fedpkg command switched to python3 on Fedora 29 and RHEL > 7:
%if 0%{?fedora} > 28 || 0%{?rhel} > 7
%bcond_with python2
%else
%bcond_without python2
%endif

BuildRequires:  pkgconfig
BuildRequires:  bash-completion
BuildRequires:  git

Requires:       bodhi-client
Requires:       fedora-packager
Requires:       koji
Requires:       redhat-rpm-config

%if %{with python2}
# This package redefines __python and can use the python_ macros
%global __python %{__python2}

BuildRequires:  python2-devel
# We br these things for man page generation due to imports
BuildRequires:  python2-rpkg >= 1.58-8
BuildRequires:  python2-distro
# This until fedora-cert gets fixed
BuildRequires:  python2-fedora
# For testing
BuildRequires:  python2-mock
BuildRequires:  python2-freezegun

%if 0%{?rhel}
BuildRequires:  python-unittest2
%else
BuildRequires:  python2-unittest2
%endif

%if 0%{?rhel} && 0%{?rhel} < 7
BuildRequires:  python-nose
BuildRequires:  python-setuptools
%else
BuildRequires:  python2-nose
BuildRequires:  python2-setuptools
%endif

%if (0%{?fedora} && 0%{?fedora} <= 27) || (0%{?rhel} && 0%{?rhel} <= 7)
BuildRequires:  python-bugzilla
Requires:       python-bugzilla
%else
BuildRequires:  python2-bugzilla
Requires:       python2-bugzilla
%endif

Requires:       python2-rpkg >= 1.58-8
Requires:       python2-distro
Requires:       python2-fedora
Requires:       python2-openidc-client >= 0.6.0

%else
# This package redefines __python and can use the python_ macros
%global __python %{__python3}

BuildRequires:  python3-devel
BuildRequires:  python3-rpkg >= 1.58-8
BuildRequires:  python3-distro
# This until fedora-cert gets fixed
BuildRequires:  python3-fedora
# For testing
BuildRequires:  python3-mock
BuildRequires:  python3-nose
BuildRequires:  python3-setuptools
BuildRequires:  python3-bugzilla
BuildRequires:  python3-freezegun
# BuildRequires:  python3-bodhi-client


Requires:       python3-bugzilla
Requires:       python3-rpkg >= 1.58-8
Requires:       python3-distro
Requires:       python3-fedora
Requires:       python3-openidc-client >= 0.6.0
Requires:       python3-bodhi-client
Requires:       python3-setuptools
%endif


%description
Provides the fedpkg command for working with dist-git

%package        -n fedpkg-stage
Summary:        Fedora utility for working with dist-git
Requires:       %{name} = %{version}-%{release}

%description    -n fedpkg-stage
Provides the fedpkg command for working with dist-git

%prep
%setup -q -n %{name}

%build
%py_build
%{__python} doc/fedpkg_man_page.py > fedpkg.1


%install
%py_install
%{__install} -d %{buildroot}%{_mandir}/man1
%{__install} -p -m 0644 fedpkg.1 %{buildroot}%{_mandir}/man1
%if 0%{?rhel} && 0%{?rhel} == 7
# The completion file must be named similarly to the command.
mv %{buildroot}%{compdir}/fedpkg.bash %{buildroot}%{compdir}/fedpkg
%endif


%check
%if 0%{?rhel} == 6
# cannot use -m nose on EL6 (python 2.6)
nosetests
%else
%{__python} -m nose
%endif



%files
%doc README.rst CHANGELOG.rst
%license COPYING
%config(noreplace) %{_sysconfdir}/rpkg/fedpkg.conf
%(dirname %{compdir})
%{_bindir}/%{name}
%{_mandir}/*/*
# For noarch packages: sitelib
%{python_sitelib}/%{name}
%{python_sitelib}/%{name}-%{version}-py*.egg-info
# zsh completion
%{_datadir}/zsh/site-functions/_%{name}

%files  stage
%{_bindir}/%{name}-stage
%config(noreplace) %{_sysconfdir}/rpkg/fedpkg-stage.conf


%changelog
* Fri Dec 06 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-16.20191206gite9889c3b
- Update to git: e9889c3b

* Mon Dec 02 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-15.20191202git83b4e00e
- Update to git: 83b4e00e

* Mon Dec 02 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-14.20191202git83b4e00e
- Update to git: 83b4e00e

* Mon Dec 02 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-13.20191202git83b4e00e
- Update to git: 83b4e00e

* Fri Nov 29 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-12.20191129gitbc13425c
- Update to git: bc13425c

* Fri Nov 29 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-11.20191129gitbc13425c
- Update to git: bc13425c

* Thu Nov 28 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-10.20191128git626d8205
- Update to git: 626d8205

* Tue Nov 26 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-9.20191126gitcc86e32e
- Update to git: cc86e32e

* Thu Nov 21 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-8.20191121git5dd6f0c0
- Update to git: 5dd6f0c0

* Tue Sep 17 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-7.20190917git1646419e
- Update to git: 1646419e

* Tue Aug 06 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-6.20190806git4c5d4c6d
- Update to git: 4c5d4c6d

* Wed Jul 31 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-5.20190731git702d6854
- Update to git: 702d6854

* Tue Jul 23 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-4.20190723git27366b3e
- Update to git: 27366b3e

* Thu Jul 18 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-3.20190718git87fa52a3
- Update to git: 87fa52a3

* Thu Jul 18 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-2.20190718gitf97d06c7
- Update to git: f97d06c7

* Wed Jul 17 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.37-1.20190717giteabb5ae7
- Update to git: eabb5ae7

* Wed Jul 17 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-29.20190717giteabb5ae7
- Update to git: eabb5ae7

* Wed Jul 17 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-28.20190717giteabb5ae7
- Update to git: eabb5ae7

* Fri Jul 12 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-27.20190712git1c21a891
- Update to git: 1c21a891

* Mon Jun 03 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-26.20190603gitc2b8c4fb
- Update to git: c2b8c4fb

* Fri May 31 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-25.20190531gitb78a5ee2
- Update to git: b78a5ee2

* Mon May 13 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-24.20190513gitdcd08c78
- Update to git: dcd08c78

* Tue Apr 30 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-23.20190430gita5ce9dd0
- Update to git: a5ce9dd0

* Fri Apr 26 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-22.20190426git231f4f98
- Update to git: 231f4f98

* Mon Apr 15 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-21.20190415gitf5579231
- Update to git: f5579231

* Thu Apr 11 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-20.20190411gitc58d0e2a
- Update to git: c58d0e2a

* Wed Apr 10 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-19.20190410git9962939d
- Update to git: 9962939d

* Mon Apr 01 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-18.20190401git06cd4372
- Update to git: 06cd4372

* Tue Mar 26 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-17.20190326git2557bf88
- Update to git: 2557bf88

* Fri Mar 15 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-16.20190315git0babd1b2
- Update to git: 0babd1b2

* Fri Mar 15 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-15.20190315gitf44c3ea9
- Update to git: f44c3ea9

* Wed Feb 20 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-14.20190220git81bc2301
- Update to git: 81bc2301

* Tue Feb 19 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-13.20190219gita66bbafa
- Update to git: a66bbafa

* Mon Feb 04 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-12.20190204gitac65bcbe
- Update to git: ac65bcbe

* Mon Feb 04 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-11.20190204git141f0010
- Update to git: 141f0010

* Mon Jan 21 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-10.20190121git53470230
- Update to git: 53470230

* Fri Jan 11 2019 lsedlar <lubomir.sedlar@gmail.com> - 1.35-9.20190111git19dc20d3
- Update to git: 19dc20d3

* Wed Nov 28 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.35-8.20181128git62bd5d9a
- Update to git: 62bd5d9a

* Tue Nov 27 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.35-7.20181127gitf2f25282
- Update to git: f2f25282

* Mon Nov 19 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.35-6.20181119gitbd554705
- Update to git: bd554705

* Thu Nov 15 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.35-5.20181115git9d02c8df
- Update to git: 9d02c8df

* Mon Nov 12 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.35-4.20181112git0045617b
- Update to git: 0045617b

* Tue Sep 04 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.35-3.20180904git64f5acfd
- Update to git: 64f5acfd

* Wed Aug 22 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.35-2.20180822git532585bb
- Update to git: 532585bb

* Tue Aug 21 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.35-1.20180821git1c3362e9
- Update to git: 1c3362e9

* Tue Aug 21 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-16.20180821git1c3362e9
- Update to git: 1c3362e9

* Mon Aug 20 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-15.20180820gitb05220e8
- Update to git: b05220e8

* Fri Aug 17 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-14.20180817git63afa015
- Update to git: 63afa015

* Thu Aug 16 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-13.20180816gitbd2a6949
- Update to git: bd2a6949

* Thu Aug 16 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-12.20180816git532470a6
- Update to git: 532470a6

* Thu Aug 16 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-11.20180816git857823e9
- Update to git: 857823e9

* Thu Aug 16 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-10.20180816gitd5838350
- Update to git: d5838350

* Wed Aug 15 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-9.20180815git053d5fb7
- Update to git: 053d5fb7

* Sun Aug 05 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-8.20180805gitc545c9da
- Update to git: c545c9da

* Wed Aug 01 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-7.20180801gitfbe1cf21
- Update to git: fbe1cf21

* Wed Aug 01 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-6.20180801git25aa80ab
- Update to git: 25aa80ab

* Mon Jul 30 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-5.20180730gitbcbb337e
- Update to git: bcbb337e

* Mon Jul 30 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-4.20180730git4711fb5b
- Update to git: 4711fb5b

* Thu Jul 26 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-3.20180726gite040c9bb
- Update to git: e040c9bb

* Wed Jul 25 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-2.20180725git32037609
- Update to git: 32037609

* Tue Jul 24 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.34-1.20180724gitf44c97f6
- Update to git: f44c97f6

* Tue Jul 24 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-18.20180724gitf44c97f6
- Update to git: f44c97f6

* Fri Jul 20 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-17.20180720git3cb5dc93
- Update to git: 3cb5dc93

* Fri Jul 20 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-16.20180720git38d23dfc
- Update to git: 38d23dfc

* Thu Jul 19 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-15.20180719git29080de8
- Update to git: 29080de8

* Wed Jul 11 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-14.20180711gitf49b556d
- Update to git: f49b556d

* Wed Jul 11 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-13.20180711gitf49b556d
- Update to git: f49b556d

* Wed Jul 11 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-12.20180711gitc4a348b7
- Update to git: c4a348b7

* Fri Jun 29 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-11.20180629gitbee9c2b5
- Update to git: bee9c2b5

* Thu Jun 28 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-10.20180628gitd1450913
- Update to git: d1450913

* Tue Jun 19 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-9.20180619git0146d168
- Update to git: 0146d168

* Tue Jun 19 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-8.20180619git0146d168
- Update to git: 0146d168

* Tue Jun 12 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-7.20180612git4c64b5bf
- Update to git: 4c64b5bf

* Mon Jun 11 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-6.20180611git06798779
- Update to git: 06798779

* Fri Jun 08 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-5.20180608gitab319fb2
- Update to git: ab319fb2

* Wed Jun 06 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-4.20180606git532c1171
- Update to git: 532c1171

* Mon Jun 04 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-3.20180604git59e97892
- Update to git: 59e97892

* Tue May 22 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-2.20180522git4ee70510
- Update to git: 4ee70510

* Mon May 14 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.33-1.20180514git3927e20d
- Update to git: 3927e20d

* Mon May 14 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.32-2.20180514git3927e20d
- Update to git: 3927e20d

* Mon May 14 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.32-1.20180514git5446155a
- Update to git: 5446155a

* Mon May 14 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-22.20180514git5446155a
- Update to git: 5446155a

* Wed Apr 25 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-21.20180425gitc529e0a0
- Update to git: c529e0a0

* Thu Apr 19 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-20.20180419gitb1d2952b
- Update to git: b1d2952b

* Sun Apr 15 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-19.20180415gitcc4b06f4
- Update to git: cc4b06f4

* Thu Apr 05 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-18.20180405gitf3319814
- Update to git: f3319814

* Wed Apr 04 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-17.20180404git5625aecc
- Update to git: 5625aecc

* Fri Mar 16 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-16.20180316gitbf62b160
- Update to git: bf62b160

* Thu Mar 01 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-15.20180301git6f295888
- Update to git: 6f295888

* Wed Feb 28 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-14.20180228gitfb4a3928
- Update to git: fb4a3928

* Mon Feb 26 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-13.20180226git00aed529
- Update to git: 00aed529

* Thu Feb 08 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-12.20180208git3d43cfba
- Update to git: 3d43cfba

* Mon Feb 05 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-11.20180205git0b2b9656
- Update to git: 0b2b9656

* Wed Jan 24 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-10.20180124git99742b32
- Update to git: 99742b32

* Mon Jan 22 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-9.20180122gitaa211444
- Update to git: aa211444

* Fri Jan 19 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-8.20180119git78d02be2
- Update to git: 78d02be2

* Tue Jan 16 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-7.20180116git0bb91bc0
- Update to git: 0bb91bc0

* Fri Jan 05 2018 lsedlar <lubomir.sedlar@gmail.com> - 1.30-6.20180105gitf7d9b568
- Update to git: f7d9b568

* Wed Nov 22 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.30-5.20171122git4cd64051
- Update to git: 4cd64051

* Wed Nov 08 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.30-4.20171108git8fde2b2f
- Update to git: 8fde2b2f

* Thu Nov 02 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.30-3.20171102git284618eb
- Update to git: 284618eb

* Tue Oct 24 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.30-2.20171024git928166f0
- Update to git: 928166f0

* Tue Oct 24 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.30-1.20171024git928166f0
- Update to git: 928166f0

* Tue Oct 24 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.29-13.20171024git928166f0
- Update to git: 928166f0

* Fri Oct 20 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.29-12.20171020git3dba1ad9
- Update to git: 3dba1ad9

* Fri Oct 20 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.29-11.20171020git3dba1ad9
- Update to git: 3dba1ad9

* Thu Oct 19 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.29-10.20171019git7896f38f
- Update to git: 7896f38f

* Thu Oct 19 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.29-9.20171019gitcd0bbdb2
- Update to git: cd0bbdb2

* Wed Oct 18 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.29-8.20171018git72bcedac
- Update to git: 72bcedac

* Mon Oct 09 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.29-7.20171009gitfc261daf
- Update to git: fc261daf

* Mon Oct 09 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.29-6.20171009git28baa8fb
- Update to git: 28baa8fb

* Tue Sep 26 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.29-5.20170926gitf9c191a8
- Update to git: f9c191a8

* Mon Sep 25 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.29-4.20170925gitaf1360fa
- Update to git: af1360fa

* Mon Sep 25 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.29-3.20170925git9b3478b9
- Update to git: 9b3478b9

* Thu Sep 21 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.29-2.20170921gite2444db0
- Update to git: e2444db0

* Wed Sep 20 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.29-1.20170920git6cfbc82c
- Update to git: 6cfbc82c

* Thu Nov 24 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-18.20161124git6d07d317
- Update to git: 6d07d317

* Wed Nov 23 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-17.20161123git641fc876
- Update to git: 641fc876

* Wed Nov 23 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-16.20161123git8feed75d
- Update to git: 8feed75d

* Wed Nov 23 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-15.20161123git8feed75d
- Update to git: 8feed75d

* Thu Nov 10 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-14.20161110git83103a2a
- Update to git: 83103a2a

* Mon Nov 07 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-13.20161107git40051569
- Update to git: 40051569

* Mon Nov 07 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-12.20161107git6c9a5188
- Update to git: 6c9a5188

* Mon Oct 03 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-11.20161003gitac5458e9
- Update to git: ac5458e9

* Mon Oct 03 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-10.20161003gitac5458e9
- Update to git: ac5458e9

* Sat Oct 01 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-9.20161001gitac5458e9
- Update to git: ac5458e9

* Fri Sep 30 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-8.20160930git44d19253
- Update to git: 44d19253

* Thu Sep 29 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-7.20160929gitcc948508
- Update to git: cc948508

* Thu Sep 29 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-6.20160929gitcc948508
- Update to git: cc948508

* Thu Sep 29 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-5.20160929gitcc948508
- Update to git: cc948508

* Thu Sep 29 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-5.20160929git8333ab3a
- Update to git: 8333ab3a

* Thu Sep 29 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-5.20160929git8333ab3a
- Update to git: 8333ab3a

* Thu Sep 29 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-4.20160929git293dc314
- Update to git: 293dc314

* Wed Sep 28 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-3.20160928git0de82243
- Update to git: 0de82243

* Tue Sep 06 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-2.20160906git13303e8b
- Update to git: 13303e8b

* Tue Sep 06 2016 lsedlar <lubomir.sedlar@gmail.com> - 1.25-2.20160906git13303e8b
- Update to git: 13303e8b

* Thu Sep 01 2016 Chenxiong Qi <cqi@redhat.com> - 1.25-1
- update project URL (mattdm)
- Allow fedpkg to be compatible with both bodhi 1 and bodhi 2. (randy)
- Modify the bodhi cli usage for `fedpkg update`. (lmacken)
- Add nosetest configuration (cqi)
- replace gitbuildurl with gitbuildhash (cqi)

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.24-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Fri Jul 08 2016 Chenxiong Qi <cqi@redhat.com> - 1.24-3
- Depends on pyrpkg 1.45

* Mon Jun 27 2016 Chenxiong Qi <cqi@redhat.com> - 1.24-1
- Add a guide for releasing new version (lsedlar)
- Merge #10 `Python 3 compatibility fixes` (lubomir.sedlar)
- Add ZSH completion by Alexey I. Froloff (lsedlar)
- Merge #28 `fix broken when non-ASCII in path` (lubomir.sedlar)
- fix broken when non-ASCII in path (cqi)
- Fix tests for retire with new rpkg (lsedlar)
- use setup.cfg to make bztar as the default format for sdist (cqi)
- Configure git user for tests (lsedlar)
- Fix tests on Python 2.6 (lsedlar)
- Python 3 compatibility fixes (ville.skytta)

* Wed Jun 08 2016 Lubomír Sedlář <lsedlar@redhat.com> - 1.23-3
- Rename bash completion on EPEL

* Thu Jun 02 2016 Lubomír Sedlář <lsedlar@redhat.com> - 1.23-2
- Add build dep on bash-completion

* Thu Mar 31 2016 Lubomír Sedlář <lubomir.sedlar@gmail.com> - 1.23-1
- Fix fedpkg retire with namespace
- Enable test suite during build

* Sun Mar 20 2016 Lubomír Sedlář <lubomir.sedlar@gmail.com> - 1.22-3
- Bump dependency on rpkg

* Wed Mar 16 2016 Lubomír Sedlář <lubomir.sedlar@gmail.com> - 1.22-2
- Bump version

* Mon Mar 14 2016 Lubomír Sedlář <lubomir.sedlar@gmail.com> - 1.22-1
- Update upstream URL (lsedlar)
- Fix bash completion. (lsedlar)
- add container-build bash completion and enable distgit namepacing (provided
  by pyrpkg) (maxamillion)
- Install bash completion to where bash-completion.pc says (ville.skytta)
- flake8 fixes (ville.skytta)
- Python 3 compatibility fixes (ville.skytta)

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.21-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Oct 23 2015 Pavol Babincak <pbabinca@redhat.com> - 1.21-1
- Use rpkg's backwards compatible clone_config (pbabinca)
- Merge #7 `Fix Deprecation warning during fedpkg update run`
  (kumarpraveen.nitdgp)
- Fix Deprecation Warning - /usr/lib/python2.7/site-packages/fedpkg/cli.py:1:
  DeprecationWarning:   Commands._hash_file is deprecated and will be removed
  eventually (kumarpraveen.nitdgp)
- Merge #3 `Add post-clone bz and sendemail config, requires rpkg > 1.36`
  (ville.skytta)
- Add post-clone bz and sendemail config, requires rpkg > 1.36 (ville.skytta)
- lookaside: Use our new download path (bochecha)
- Simplify handling of our custom certificates (bochecha)
- Drop obsolete functions (bochecha)
- Release 1.20 (pbabinca)
- Bash completion for mockbuild --no-clean* options (pbabinca)
- Hijack load_kojisession to catch auth problems (pbabinca)
- Upload source files with our preferred hash (bochecha)
- pass keyword args as keyword args (mikeb)
- For rawhide use fedora-rawhide-* mock config instead of fedora-devel-*
  (pbabinca)

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.20-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Apr 14 2015 Pavol Babincak <pbabinca@redhat.com> - 1.20-1
- Bash completion for mockbuild --no-clean* options (pbabinca)
- Hijack load_kojisession to catch auth problems (pbabinca)
- Upload source files with our preferred hash (bochecha)
- pass keyword args as keyword args (mikeb)
- For rawhide use fedora-rawhide-* mock config instead of fedora-devel-*
  (pbabinca)

* Thu Dec 18 2014 Pavol Babincak <pbabinca@redhat.com> - 1.19-2
- Remove python-offtrac from {build,}requires (rhbz#1157793)

* Fri Sep 26 2014 Pavol Babincak - 1.19-1
- Explicitly define fedpkg name for man pages (pbabinca)
- Remove (pbabinca)
- Revert "refactor: PEP 8 compliance of __init__.py" (pbabinca)
- refactor: PEP 8 compliance of __init__.py (pbabinca)
- refactor: PEP 8 compliance (pbabinca)
- retire: Ask for password only when required (opensource)
- fedpkg: Show full exception if verbose (opensource)
- add new s390 only packages (dan)
- add new ppc only packages (dan)

* Tue Jul 29 2014 Pavol Babincak <pbabinca@redhat.com> - 1.18-1
- Remove spec file again (pbabinca)
- Remove fedpkg-fixbranches as it isn't needed anymore (pbabinca)
- Remove offtrac module as we don't use Trac for buildroot override (pbabinca)
- Default name of executable if isn't possible to determine it (pbabinca)
- Allow executable name to be used as key for configuration (pbabinca)
- completion: Add mockbuild --root completion (ville.skytta)
- completion: Assume fedpkg is installed if the completion is, no need to test
  (ville.skytta)
- fix date in 1.11-2 changelog

* Tue Jul 29 2014 Dennis Gilmore <dennis@ausil.us> 1.17-3
- add missing Requires

* Fri Jul 04 2014 Pavol Babincak <pbabinca@redhat.com> - 1.17-2
- Use tar.bz2 archive which spec expects instead of tar.gz

* Fri Jul 04 2014 Pavol Babincak <pbabinca@redhat.com> - 1.17-1
- Removed spec as fedpkg is now in dist-git (pbabinca)
- Fix retirement (bochecha)

* Tue Jun 24 2014 Dennis Gilmore <dennis@ausil.us> - 1.16-1
- retire: Make retirement message/reason mandatory (opensource)
- retire: Use pkgdb2 API (opensource)
- Don't check for the config file if the user is asking for help (bochecha)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.15-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Dec 16 2013 <dennis@ausil.us> - 1.15-1
- remove tag-request we no longer use that work flow, the process is managed
  via blocker bugs now (dennis)
- use the rpm changelog as default update template patch from
  https://bugzilla.redhat.com/show_bug.cgi?id=1023915 (dennis)
- allow epel branches to be epel<release> clean up overrides (dennis)
- Fix log message (bochecha)

* Mon Aug 26 2013 Dennis Gilmore <dennis@ausil.us> - 1.14-1
- clean up arches in fedpkg bash completeion - drop sparc - add i686 - add arm
  variants - add ppc64p7 (dennis)
- Add arm7hl to bash completion arches (opensource)
- Add more ppc64-only packages (opensource)
- remove --push from retire command in bash completion (opensource)
- undefine macros rather than define as nil (dennis)

* Sat Aug 24 2013 Dennis Gilmore <dennis@ausil.us> - 1.13-1
- Rework --retire (opensource)

* Sat Aug 24 2013 Dennis Gilmore <dennis@ausil.us> - 1.12-1
- update ppc secondary arch packages, remove sparc, point to new seconary arch
  config location (dennis)
- retire packages in packagedb as well (opensource)
- Move fedpkg to own module (opensource)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.11-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.11-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sun Jan 06 2013 Tom Callaway <spot@fedoraproject.org> - 1.11-2
- use --eval '%%undefine to unset dist values instead of nil (bz876308)

* Tue Nov 06 2012 Jesse Keating <jkeating@redhat.com> - 1.11-1
- Unset runtime disttag (spot)
- use nil to unset dist values. (spot)

* Tue Oct 09 2012 Jesse Keating <jkeating@redhat.com> - 1.10-1
- Force invalid dist values to 0 (spot) (jkeating)
- Fix a traceback in fixbranches (#817478) (jkeating)

* Mon Mar 12 2012 Jesse Keating <jkeating@redhat.com> - 1.9-1
- Wrap the prune command in a try (rhbz#785820) (jkeating)
- Use koji if we have it to get master details (rhbz#785234) (jkeating)
- Always send builds from master to 'rawhide' (rhbz#785234) (jkeating)
- Handle fedpkg calls not from a git repo (rhbz#785776) (jkeating)

* Thu Mar 01 2012 Jesse Keating <jkeating@redhat.com> - 1.8-1
- More completion fixes (jkeating)
- Add mock-config and mockbuild completion (jkeating)
- Simplify test for fedpkg availability. (ville.skytta)
- Fix ~/... path completion. (ville.skytta)
- Add --raw to bash completion (jkeating)
- Make things quiet when possible (jkeating)
- Fix property variables (jkeating)

* Sat Jan 14 2012 Jesse Keating <jkeating@redhat.com> - 1.7-1
- Adapt property overloading to new-style class. (bochecha)
- Use super(), now that rpkg uses new-style classes everywhere (bochecha)
- Add gitbuildurl to the bash completion. (jkeating)
- Handle koji config with unknown module name (jkeating)

* Mon Nov 21 2011 Jesse Keating <jkeating@redhat.com> - 1.6-1
- Replace -c with -C for the --config option (jkeating)
- Package up fedpkg-fixbranches (#751507) (jkeating)
- Use old style of super class calls (jkeating)

* Mon Nov 07 2011 Jesse Keating <jkeating@redhat.com> - 1.5-1
- Pass along the return value from import_srpm (jkeating)
- Whitespace cleanup (jkeating)

* Mon Nov 07 2011 Jesse Keating <jkeating@redhat.com> - 1.4-1
- Use the GPLv2 content for COPYING to match intent. (jkeating)

* Thu Nov 03 2011 Jesse Keating <jkeating@redhat.com> - 1.3-1
- Fix buildrequires (jkeating)
- Don't register a nonexestant target (jkeating)
- Drop koji-rhel.conf file (jkeating)
- Fix up the setup.py (jkeating)

* Thu Nov 03 2011 Jesse Keating <jkeating@redhat.com> - 1.2-1
- Catch raises in the libraries (jkeating)
- Fix the fixbranches script for new module name (jkeating)
- srpm takes arguments, pass them along (jkeating)
- Get error output from user detection failures (jkeating)
- Get the user name from the Fedora SSL certificate. (bochecha)
- Fix crash when detecting Rawhide. (bochecha)

* Fri Oct 28 2011 Jesse Keating <jkeating@redhat.com> - 1.1-1
- Overload curl stuff (jkeating)
- Hardcode fedpkg version requires (jkeating)
- Fix up changelog date (jkeating)
